@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.006000';
+our $VERSION = '0.006001';
 
 use List::AllUtils qw( all none );
 use Stepford::Error;
@@ -224,7 +224,7 @@ sub step_is_up_to_date {
             . '. The following children have newer last run times: '
             . join ', ',
         map { $_->step_class . ' (' . $_->last_run_time . ')' }
-            @newer_children
+            @newer_children,
     );
 
     return 0;
@@ -290,10 +290,8 @@ sub is_serializable {
 
     # A step can be serialized as long as it and all of its children do not
     # implement Stepford::Role::Step::Unserializable
-    none {
-        $_->step_class->does('Stepford::Role::Step::Unserializable')
-    }
-    ( $self, @{ $self->_children_graphs } );
+    none { $_->step_class->does('Stepford::Role::Step::Unserializable') }
+        ( $self, @{ $self->_children_graphs } );
 }
 
 sub as_string {
@@ -305,7 +303,7 @@ sub as_string {
             map { sprintf( '[ %s ] --> [ %s ]', @$_ ) }
                 _parent_child_pairs($self)
         ),
-        q{}
+        q{},
     );
 }
 
@@ -352,7 +350,7 @@ Stepford::Graph - Contains the step dependency graph
 
 =head1 VERSION
 
-version 0.006000
+version 0.006001
 
 =head1 DESCRIPTION
 
@@ -377,7 +375,7 @@ Dave Rolsky <drolsky@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 - 2019 by MaxMind, Inc.
+This software is copyright (c) 2014 - 2023 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
