@@ -3,7 +3,7 @@ package Stepford::Types;
 use strict;
 use warnings;
 
-our $VERSION = '0.006000';
+our $VERSION = '0.006001';
 
 use MooseX::Types::Common::Numeric;
 use MooseX::Types::Moose;
@@ -11,14 +11,12 @@ use MooseX::Types::Path::Class;
 
 use parent 'MooseX::Types::Combine';
 
-__PACKAGE__->provide_types_from(
-    qw(
-        MooseX::Types::Common::Numeric
-        MooseX::Types::Moose
-        MooseX::Types::Path::Class
-        Stepford::Types::Internal
-        )
-);
+__PACKAGE__->provide_types_from( qw(
+    MooseX::Types::Common::Numeric
+    MooseX::Types::Moose
+    MooseX::Types::Path::Class
+    Stepford::Types::Internal
+) );
 
 1;
 
@@ -36,7 +34,7 @@ Stepford::Types - Type library used in Stepford classes/roles
 
 =head1 VERSION
 
-version 0.006000
+version 0.006001
 
 =head1 SUPPORT
 
@@ -48,7 +46,7 @@ Dave Rolsky <drolsky@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 - 2019 by MaxMind, Inc.
+This software is copyright (c) 2014 - 2023 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
